# Plasma Cylinder

[![code testing](https://github.com/plasmacan/cylinder/actions/workflows/testing.yaml/badge.svg)](https://github.com/plasmacan/cylinder/actions/workflows/testing.yaml)
[![CodeQL](https://github.com/plasmacan/cylinder/actions/workflows/codeql.yaml/badge.svg)](https://github.com/plasmacan/cylinder/actions/workflows/codeql.yaml)
[![code coverage](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/plasmacan/cylinder/main/.repo-shields/covered_shield.json)](.repo-reports/coverage.txt)
[![code quality](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/plasmacan/cylinder/main/.repo-shields/quality_shield.json)](.repo-reports/ruff-report.txt)
[![PyPI version](https://badge.fury.io/py/cylinder.svg)](https://badge.fury.io/py/cylinder)

Plasma Cylinder is a Python web application micro framework built atop
[werkzeug](https://werkzeug.palletsprojects.com) utilizing file-based routing. It is designed to be
production-ready with 100% test coverage.

For additional information please review the full documentation at
[plasmacan.github.io/cylinder](https://plasmacan.github.io/cylinder/)
